@@ -4,11 +4,12 @@
 
 __author__ = """The pyfar developers"""
 __email__ = ''
-__version__ = '0.4.3'
+__version__ = '0.5.2'
 
 
 from .classes.audio import Signal, TimeData, FrequencyData
-from .classes.audio import add, subtract, multiply, divide, power
+from .classes.audio import (add, subtract, multiply, divide, power,
+                            matrix_multiplication)
 from .classes.coordinates import Coordinates
 from .classes.orientations import Orientations
 from .classes.filter import FilterFIR, FilterIIR, FilterSOS
@@ -29,6 +30,7 @@ __all__ = [
     'multiply',
     'divide',
     'power',
+    'matrix_multiplication',
     'Coordinates',
     'Orientations',
     'FilterFIR',
