@@ -1,4 +1,3 @@
-import matplotlib as mpl
 import numpy as np
 from pyfar import Signal, TimeData, FrequencyData
 import pyfar.dsp as dsp
@@ -12,27 +11,24 @@ from .ticker import (
 
 
 def _time_2d(signal, dB, log_prefix, log_reference, unit, indices,
-             orientation, cmap, colorbar, ax, **kwargs):
+             orientation, method, colorbar, ax, **kwargs):
 
     # check input and prepare the figure, axis, and common parameters
     fig, ax, indices, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal, TimeData), 2, indices, ax, colorbar, **kwargs)
+        signal, (Signal, TimeData), 2, indices, method, ax, colorbar, **kwargs)
     _utils._check_time_unit(unit)
 
     # prepare input
     kwargs = _utils._return_default_colors_rgb(**kwargs)
-    data = signal.time.T if orientation == "vertical" else signal.time
     if dB:
-        if log_prefix is None:
-            log_prefix = _utils._log_prefix(signal)
-        # avoid any zero-values because they result in -inf in dB data
-        eps = np.finfo(float).eps
-        data = log_prefix * np.log10(np.abs(data) / log_reference + eps)
+        data = dsp.decibel(signal, 'time', log_prefix, log_reference)
         ymax = np.nanmax(data) + 10
         ymin = ymax - 100
-
+    else:
+        data = signal.time
+    data = data.T if orientation == "vertical" else data
     # auto detect the time unit
-    if unit is None:
+    if unit in [None, "auto"]:
         unit = _utils._time_auto_unit(signal.times[..., -1])
     # set the unit
     if unit == 'samples':
@@ -52,15 +48,18 @@ def _time_2d(signal, dB, log_prefix, log_reference, unit, indices,
     axis[0].set_label_text(f"Time in {unit}")
     ax_lim[0](times[0], times[-1])
 
+    # color limits
+    if dB and "vmin" not in kwargs:
+        kwargs["vmin"] = ymin
+    if dB and "vmax" not in kwargs:
+        kwargs["vmax"] = ymax
+
     # plot data
     indices_x = indices if orientation == "vertical" else times
     indices_y = times if orientation == "vertical" else indices
-    qm = ax[0].pcolormesh(indices_x, indices_y, data, cmap=cmap, **kwargs)
-
-    # color limits and colorbar
-    if dB:
-        qm.set_clim(ymin, ymax)
+    qm = _plot_2d(indices_x, indices_y, data, method, ax[0], **kwargs)
 
+    # colorbar
     cb = _utils._add_colorbar(colorbar, fig, ax, qm,
                               "Amplitude in dB" if dB else "Amplitude")
 
@@ -68,27 +67,24 @@ def _time_2d(signal, dB, log_prefix, log_reference, unit, indices,
 
 
 def _freq_2d(signal, dB, log_prefix, log_reference, freq_scale, indices,
-             orientation, cmap, colorbar, ax, **kwargs):
+             orientation, method, colorbar, ax, **kwargs):
 
     # check input and prepare the figure, axis, and common parameters
     fig, ax, indices, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal, FrequencyData), 2, indices, ax, colorbar, **kwargs)
+        signal, (Signal, FrequencyData), 2, indices, method, ax, colorbar,
+        **kwargs)
     _utils._check_axis_scale(freq_scale)
 
     # prepare input
     kwargs = _utils._return_default_colors_rgb(**kwargs)
-    data = signal.freq.T if orientation == "vertical" else signal.freq
     if dB:
-        if log_prefix is None:
-            log_prefix = _utils._log_prefix(signal)
-        eps = np.finfo(float).eps
-        data = log_prefix*np.log10(np.abs(data)/log_reference + eps)
+        data = dsp.decibel(signal, 'freq', log_prefix, log_reference)
         ymax = np.nanmax(data)
         ymin = ymax - 90
         ymax = ymax + 10
     else:
-        data = np.abs(data)
-
+        data = np.abs(signal.freq)
+    data = data.T if orientation == "vertical" else data
     # setup axis label and data
     axis = [ax[0].yaxis, ax[0].xaxis]
     ax_lim = [ax[0].set_ylim, ax[0].set_xlim]
@@ -107,27 +103,31 @@ def _freq_2d(signal, dB, log_prefix, log_reference, freq_scale, indices,
         axis[0].set_major_locator(LogLocatorITAToolbox())
     axis[0].set_major_formatter(LogFormatterITAToolbox())
 
+    # color limits
+    if dB and "vmin" not in kwargs:
+        kwargs["vmin"] = ymin
+    if dB and "vmax" not in kwargs:
+        kwargs["vmax"] = ymax
+
     # plot data
     indices_x = indices if orientation == "vertical" else signal.frequencies
     indices_y = signal.frequencies if orientation == "vertical" else indices
-    qm = ax[0].pcolormesh(indices_x, indices_y, data, cmap=cmap, **kwargs)
-
-    # color limits and colorbar
-    if dB:
-        qm.set_clim(ymin, ymax)
+    qm = _plot_2d(indices_x, indices_y, data, method, ax[0], **kwargs)
 
+    # colorbar
     cb = _utils._add_colorbar(colorbar, fig, ax, qm,
                               "Magnitude in dB" if dB else "Magnitude")
 
     return ax[0], qm, cb
 
 
-def _phase_2d(signal, deg, unwrap, freq_scale, indices, orientation, cmap,
+def _phase_2d(signal, deg, unwrap, freq_scale, indices, orientation, method,
               colorbar, ax, **kwargs):
 
     # check input and prepare the figure, axis, and common parameters
     fig, ax, indices, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal, FrequencyData), 2, indices, ax, colorbar, **kwargs)
+        signal, (Signal, FrequencyData), 2, indices, method, ax, colorbar,
+        **kwargs)
     _utils._check_axis_scale(freq_scale)
 
     # prepare input
@@ -147,20 +147,24 @@ def _phase_2d(signal, deg, unwrap, freq_scale, indices, orientation, cmap,
     axis[0].set_label_text("Frequency in Hz")
     ax_lim[0](_utils._lower_frequency_limit(signal), signal.frequencies[-1])
 
+    # color limits
+    phase_margin = 5 if deg else np.radians(5)
+    if "vmin" not in kwargs:
+        kwargs["vmin"] = np.nanmin(data) - phase_margin
+    if "vmax" not in kwargs:
+        kwargs["vmax"] = np.nanmax(data) + phase_margin
+
     # plot data
     indices_x = indices if orientation == "vertical" else signal.frequencies
     indices_y = signal.frequencies if orientation == "vertical" else indices
-    qm = ax[0].pcolormesh(indices_x, indices_y, data, cmap=cmap, **kwargs)
+    qm = _plot_2d(indices_x, indices_y, data, method, ax[0], **kwargs)
 
     ax_scale[0](freq_scale)
     if freq_scale == "log":
         axis[0].set_major_locator(LogLocatorITAToolbox())
     axis[0].set_major_formatter(LogFormatterITAToolbox())
 
-    # color limits and colorbar
-    phase_margin = 5 if deg else np.radians(5)
-    qm.set_clim(np.nanmin(data) - phase_margin, np.nanmax(data) + phase_margin)
-
+    # colorbar
     cb = _utils._add_colorbar(colorbar, fig, ax, qm,
                               _utils._phase_label(unwrap, deg))
 
@@ -175,12 +179,12 @@ def _phase_2d(signal, deg, unwrap, freq_scale, indices, orientation, cmap,
     return ax[0], qm, cb
 
 
-def _group_delay_2d(signal, unit, freq_scale, indices, orientation, cmap,
+def _group_delay_2d(signal, unit, freq_scale, indices, orientation, method,
                     colorbar, ax, **kwargs):
 
     # check input and prepare the figure, axis, and common parameters
     fig, ax, indices, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal, ), 2, indices, ax, colorbar, **kwargs)
+        signal, (Signal, ), 2, indices, method, ax, colorbar, **kwargs)
     _utils._check_axis_scale(freq_scale)
 
     # prepare input
@@ -215,22 +219,26 @@ def _group_delay_2d(signal, unit, freq_scale, indices, orientation, cmap,
         axis[0].set_major_locator(LogLocatorITAToolbox())
     axis[0].set_major_formatter(LogFormatterITAToolbox())
 
+    # color limits
+    if "vmin" not in kwargs:
+        kwargs["vmin"] = .5 * np.nanmin(data)
+    if "vmax" not in kwargs:
+        kwargs["vmax"] = 1.5 * np.nanmax(data)
+
     # plot data
     indices_x = indices if orientation == "vertical" else signal.frequencies
     indices_y = signal.frequencies if orientation == "vertical" else indices
-    qm = ax[0].pcolormesh(indices_x, indices_y, data, cmap=cmap, **kwargs)
-
-    # color limits and colorbar
-    qm.set_clim(.5 * np.nanmin(data), 1.5 * np.nanmax(data))
+    qm = _plot_2d(indices_x, indices_y, data, method, ax[0], **kwargs)
 
+    # colorbar
     cb = _utils._add_colorbar(colorbar, fig, ax, qm, f"Group delay in {unit}")
 
     return ax[0], qm, cb
 
 
 def _time_freq_2d(signal, dB_time, dB_freq, log_prefix_time, log_prefix_freq,
-                  log_reference, freq_scale, unit, indices, orientation, cmap,
-                  colorbar, ax, **kwargs):
+                  log_reference, freq_scale, unit, indices, orientation,
+                  method, colorbar, ax, **kwargs):
     """
     Plot the time signal and magnitude spectrum in a 2 by 1 subplot layout.
     """
@@ -239,26 +247,28 @@ def _time_freq_2d(signal, dB_time, dB_freq, log_prefix_time, log_prefix_freq,
 
     _, qm_0, cb_0 = _time_2d(
         signal, dB_time, log_prefix_time, log_reference, unit, indices,
-        orientation, cmap, colorbar, ax[0], **kwargs)
+        orientation, method, colorbar, ax[0], **kwargs)
     _, qm_1, cb_1 = _freq_2d(
         signal, dB_freq, log_prefix_freq, log_reference, freq_scale, indices,
-        orientation, cmap, colorbar, ax[1], **kwargs)
+        orientation, method, colorbar, ax[1], **kwargs)
     fig.align_ylabels()
 
     return ax, [qm_0, qm_1], [cb_0, cb_1]
 
 
 def _freq_phase_2d(signal, dB, log_prefix, log_reference, freq_scale, deg,
-                   unwrap, indices, orientation, cmap, colorbar, ax, **kwargs):
+                   unwrap, indices, orientation, method, colorbar, ax,
+                   **kwargs):
     """Plot the magnitude and phase spectrum in a 2 by 1 subplot layout."""
 
     fig, ax = _utils._prepare_plot(ax, (2, 1))
 
     _, qm_0, cb_0 = _freq_2d(signal, dB, log_prefix, log_reference, freq_scale,
-                             indices, orientation, cmap, colorbar, ax[0],
-                             **kwargs)
+                             indices, orientation, method, colorbar,
+                             ax[0], **kwargs)
     _, qm_1, cb_1 = _phase_2d(signal, deg, unwrap, freq_scale, indices,
-                              orientation, cmap, colorbar, ax[1], **kwargs)
+                              orientation, method, colorbar, ax[1],
+                              **kwargs)
     ax[0].set_xlabel(None)
     fig.align_ylabels()
 
@@ -267,7 +277,7 @@ def _freq_phase_2d(signal, dB, log_prefix, log_reference, freq_scale, deg,
 
 def _freq_group_delay_2d(
         signal, dB, log_prefix, log_reference, unit, freq_scale, indices,
-        orientation, cmap, colorbar, ax, **kwargs):
+        orientation, method, colorbar, ax, **kwargs):
     """
     Plot the magnitude and group delay spectrum in a 2 by 1 subplot layout.
     """
@@ -275,11 +285,11 @@ def _freq_group_delay_2d(
     fig, ax = _utils._prepare_plot(ax, (2, 1))
 
     _, qm_0, cb_0 = _freq_2d(signal, dB, log_prefix, log_reference, freq_scale,
-                             indices, orientation, cmap, colorbar, ax[0],
-                             **kwargs)
+                             indices, orientation, method, colorbar,
+                             ax[0], **kwargs)
     _, qm_1, cb_1 = _group_delay_2d(
-        signal, unit, freq_scale, indices, orientation, cmap, colorbar, ax[1],
-        **kwargs)
+        signal, unit, freq_scale, indices, orientation, method,
+        colorbar, ax[1], **kwargs)
     ax[0].set_xlabel(None)
     fig.align_ylabels()
 
@@ -287,10 +297,9 @@ def _freq_group_delay_2d(
 
 
 def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
-                 freq_scale='linear', unit=None,
-                 window='hann', window_length=1024, window_overlap_fct=0.5,
-                 cmap=mpl.cm.get_cmap(name='magma'), colorbar=True, ax=None,
-                 **kwargs):
+                 freq_scale='linear', unit="s", window='hann',
+                 window_length=1024, window_overlap_fct=0.5,
+                 colorbar=True, ax=None, **kwargs):
     """Plot the magnitude spectrum versus time.
 
     See pyfar.line.spectogram for more information.
@@ -305,7 +314,7 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
     # check input
     # check input and prepare the figure and axis
     fig, ax, _, kwargs = _utils._prepare_2d_plot(
-        signal, (Signal, ), 1, None, ax, colorbar, **kwargs)
+        signal, (Signal, ), 1, None, 'pcolormesh', ax, colorbar, **kwargs)
     _utils._check_time_unit(unit)
     _utils._check_axis_scale(freq_scale, 'y')
 
@@ -332,7 +341,7 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
             np.abs(spectrogram) / log_reference + eps)
 
     # auto detect the time unit
-    if unit is None:
+    if unit in [None, "auto"]:
         unit = _utils._time_auto_unit(times[..., -1])
     # set the unit
     if unit == 'samples':
@@ -342,7 +351,7 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
         times = times * factor
 
     # plot the data
-    qm = ax[0].pcolormesh(times, frequencies, spectrogram, cmap=cmap, **kwargs)
+    qm = ax[0].pcolormesh(times, frequencies, spectrogram, **kwargs)
 
     # Adjust axes:
     ax[0].set_ylabel('Frequency in Hz')
@@ -369,3 +378,21 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
                               'Magnitude in dB' if dB else 'Magnitude')
 
     return ax[0], qm, cb
+
+
+def _plot_2d(x, y, data, method, ax, **kwargs):
+    # Choose method and plot
+    if method == 'contourf':
+        # adjust levels according to vmin and vmax
+        if "vmin" in kwargs and "vmax" in kwargs:
+            if "levels" not in kwargs:
+                # Default: 11 levels
+                kwargs["levels"] = np.linspace(
+                    kwargs["vmin"], kwargs["vmax"], 11)
+            elif isinstance(kwargs["levels"], int):
+                kwargs["levels"] = np.linspace(
+                    kwargs["vmin"], kwargs["vmax"], kwargs["levels"])
+        qm = ax.contourf(x, y, data, **kwargs)
+    else:
+        qm = ax.pcolormesh(x, y, data, **kwargs)
+    return qm
