@@ -4,8 +4,8 @@ from . import _interaction as ia
 import warnings
 
 
-def time(signal, dB=False, log_prefix=20, log_reference=1, unit=None, ax=None,
-         style='light', **kwargs):
+def time(signal, dB=False, log_prefix=20, log_reference=1, unit="s",
+         ax=None, style='light', **kwargs):
     """Plot the time signal.
 
     Plots ``signal.time`` and passes keyword arguments (`kwargs`) to
@@ -28,10 +28,19 @@ def time(signal, dB=False, log_prefix=20, log_reference=1, unit=None, ax=None,
         Reference for calculating the logarithmic time data. The default is
         ``1``.
     unit : str, None
-        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     ax : matplotlib.pyplot.axes
         Axes to plot on. The default is ``None``, which uses the current axis
         or creates a new figure if none exists.
@@ -236,7 +245,7 @@ def phase(signal, deg=False, unwrap=False, freq_scale='log', ax=None,
     return ax
 
 
-def group_delay(signal, unit=None, freq_scale='log', ax=None, style='light',
+def group_delay(signal, unit="s", freq_scale='log', ax=None, style='light',
                 xscale=None, **kwargs):
     """Plot the group delay.
 
@@ -250,10 +259,19 @@ def group_delay(signal, unit=None, freq_scale='log', ax=None, style='light',
         plotting, e.g, a signal of ``signal.cshape = (2, 2)`` would be plotted
         in the order ``(0, 0)``, ``(0, 1)``, ``(1, 0)``, ``(1, 1)``.
     unit : str, None
-        Unit of the group delay. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
@@ -315,7 +333,7 @@ def group_delay(signal, unit=None, freq_scale='log', ax=None, style='light',
 
 def time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
               log_prefix_freq=None, log_reference=1, freq_scale='log',
-              unit=None, ax=None, style='light', xscale=None, **kwargs):
+              unit="s", ax=None, style='light', xscale=None, **kwargs):
     """
     Plot the time signal and magnitude spectrum (2 by 1 subplot).
 
@@ -349,11 +367,20 @@ def time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
     freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
-    unit : str
-        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+    unit : str, None
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     ax : matplotlib.pyplot.axes
         Array or list with two axes to plot on. The default is ``None``, which
         uses the current axis or creates a new figure if none exists.
@@ -505,7 +532,7 @@ def freq_phase(signal, dB=True, log_prefix=None, log_reference=1,
 
 
 def freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
-                     unit=None, freq_scale='log', ax=None, style='light',
+                     unit="s", freq_scale='log', ax=None, style='light',
                      xscale=None, **kwargs):
     """Plot the magnitude and group delay spectrum (2 by 1 subplot).
 
@@ -528,11 +555,20 @@ def freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
     log_reference : integer
         Reference for calculating the logarithmic frequency data. The default
         is ``1``.
-    unit : str
-        Unit of the group delay. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+    unit : str, None
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
