@@ -1,4 +1,3 @@
-import matplotlib as mpl
 import numpy as np
 from pyfar.plot.utils import context
 from .. import Signal
@@ -7,15 +6,14 @@ from . import _interaction as ia
 import warnings
 
 
-def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
-            indices=None, orientation="vertical",
-            cmap=mpl.cm.get_cmap(name='magma'), colorbar=True, ax=None,
-            style='light', **kwargs):
+def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit="s",
+            indices=None, orientation="vertical", method='pcolormesh',
+            colorbar=True, ax=None, style='light', **kwargs):
     """
     2D color coded plot of time signals.
 
     Plots ``signal.time`` and passes keyword arguments (`kwargs`) to
-    ``matplotlib.pyplot.pcolormesh()``.
+    ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -34,10 +32,19 @@ def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
         Reference for calculating the logarithmic time data. The default is
         ``1``.
     unit : str, None
-        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     indices: array like, optional
         Points at which the channels of `signal` were sampled (e.g. azimuth
         angles or x values). `indices` must be monotonously increasing/
@@ -51,6 +58,17 @@ def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -75,7 +93,7 @@ def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
 
     Returns
@@ -86,10 +104,10 @@ def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
         colorbar. If `colorbar` is ``False``, only the axis on which the data
         is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -112,13 +130,13 @@ def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
     with context(style):
         ax, qm, cb = _two_d._time_2d(
             signal, dB, log_prefix, log_reference, unit,
-            indices, orientation, cmap, colorbar, ax, **kwargs)
+            indices, orientation, method, colorbar, ax, **kwargs)
     _utils._tight_layout()
 
     plot_parameter = ia.PlotParameter(
         'time_2d', dB_time=dB, log_prefix_time=log_prefix,
         log_reference=log_reference, unit_time=unit, indices=indices,
-        orientation=orientation, cmap=cmap, colorbar=colorbar)
+        orientation=orientation, method=method, colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax.interaction = interaction
@@ -131,13 +149,13 @@ def time_2d(signal, dB=False, log_prefix=None, log_reference=1, unit=None,
 
 def freq_2d(signal, dB=True, log_prefix=None, log_reference=1,
             freq_scale='log', indices=None, orientation="vertical",
-            cmap=mpl.cm.get_cmap(name='magma'), colorbar=True, ax=None,
-            style='light', **kwargs):
+            method='pcolormesh', colorbar=True, ax=None, style='light',
+            **kwargs):
     """
     2D color coded plot of magnitude spectra.
 
     Plots ``abs(signal.freq)`` and passes keyword arguments (`kwargs`) to
-    ``matplotlib.pyplot.pcolormesh()``.
+    ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -171,6 +189,17 @@ def freq_2d(signal, dB=True, log_prefix=None, log_reference=1,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -195,7 +224,7 @@ def freq_2d(signal, dB=True, log_prefix=None, log_reference=1,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Returns
     -------
@@ -205,10 +234,10 @@ def freq_2d(signal, dB=True, log_prefix=None, log_reference=1,
         colorbar. If `colorbar` is ``False``, only the axis on which the data
         is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -231,14 +260,14 @@ def freq_2d(signal, dB=True, log_prefix=None, log_reference=1,
     with context(style):
         ax, qm, cb = _two_d._freq_2d(
             signal, dB, log_prefix, log_reference, freq_scale, indices,
-            orientation, cmap, colorbar, ax, **kwargs)
+            orientation, method, colorbar, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'freq_2d', dB_freq=dB, log_prefix_freq=log_prefix,
         log_reference=log_reference, xscale=freq_scale, indices=indices,
-        orientation=orientation, cmap=cmap, colorbar=colorbar)
+        orientation=orientation, method=method, colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax.interaction = interaction
@@ -250,13 +279,13 @@ def freq_2d(signal, dB=True, log_prefix=None, log_reference=1,
 
 
 def phase_2d(signal, deg=False, unwrap=False, freq_scale='log', indices=None,
-             orientation="vertical", cmap=mpl.cm.get_cmap(name='magma'),
+             orientation="vertical", method='pcolormesh',
              colorbar=True, ax=None, style='light', **kwargs):
     """
     2D color coded plot of phase spectra.
 
     Plots ``angle(signal.freq)`` and passes keyword arguments (`kwargs`) to
-    ``matplotlib.pyplot.pcolormesh()``.
+    ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -285,6 +314,17 @@ def phase_2d(signal, deg=False, unwrap=False, freq_scale='log', indices=None,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -309,7 +349,7 @@ def phase_2d(signal, deg=False, unwrap=False, freq_scale='log', indices=None,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Returns
     -------
@@ -319,10 +359,10 @@ def phase_2d(signal, deg=False, unwrap=False, freq_scale='log', indices=None,
         colorbar. If `colorbar` is ``False``, only the axis on which the data
         is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -344,14 +384,14 @@ def phase_2d(signal, deg=False, unwrap=False, freq_scale='log', indices=None,
 
     with context(style):
         ax, qm, cb = _two_d._phase_2d(
-            signal, deg, unwrap, freq_scale, indices, orientation, cmap,
+            signal, deg, unwrap, freq_scale, indices, orientation, method,
             colorbar, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'phase_2d', deg=deg, unwrap=unwrap, xscale=freq_scale, indices=indices,
-        orientation=orientation, cmap=cmap, colorbar=colorbar)
+        orientation=orientation, method=method, colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax.interaction = interaction
@@ -362,14 +402,15 @@ def phase_2d(signal, deg=False, unwrap=False, freq_scale='log', indices=None,
     return ax, qm, cb
 
 
-def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
-                   orientation="vertical", cmap=mpl.cm.get_cmap(name='magma'),
+def group_delay_2d(signal, unit="s", freq_scale='log', indices=None,
+                   orientation="vertical", method='pcolormesh',
                    colorbar=True, ax=None, style='light', **kwargs):
     """
     2D color coded plot of the group delay.
 
     Plots ``pyfar.dsp.group_delay(signal.freq)`` and passes keyword arguments
-    (`kwargs`) to ``matplotlib.pyplot.pcolormesh()``.
+    (`kwargs`) to ``matplotlib.pyplot.pcolormesh()`` or
+    ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -377,10 +418,19 @@ def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
         The input data to be plotted. `signal.cshape` must be `(m, )` with
         `m>1`.
     unit : str, None
-        Unit of the group delay. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
@@ -397,6 +447,17 @@ def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -421,7 +482,7 @@ def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Returns
     -------
@@ -431,10 +492,10 @@ def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
         axis of the colorbar. If `colorbar` is ``False``, only the axes on
         which the data is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -456,14 +517,14 @@ def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
 
     with context(style):
         ax, qm, cb = _two_d._group_delay_2d(
-            signal, unit, freq_scale, indices, orientation, cmap,
+            signal, unit, freq_scale, indices, orientation, method,
             colorbar, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'group_delay_2d', unit_gd=unit, xscale=freq_scale, indices=indices,
-        orientation=orientation, cmap=cmap, colorbar=colorbar)
+        orientation=orientation, method=method, colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax.interaction = interaction
@@ -476,14 +537,15 @@ def group_delay_2d(signal, unit=None, freq_scale='log', indices=None,
 
 def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
                  log_prefix_freq=None, log_reference=1, freq_scale='log',
-                 unit=None, indices=None, orientation="vertical",
-                 cmap=mpl.cm.get_cmap(name='magma'), colorbar=True, ax=None,
-                 style='light', **kwargs):
+                 unit='s', indices=None, orientation="vertical",
+                 method='pcolormesh', colorbar=True, ax=None, style='light',
+                 **kwargs):
     """
     2D color coded plot of time signals and magnitude spectra (2 by 1 subplot).
 
     Plots ``signal.time`` and ``abs(signal.freq)`` passes keyword arguments
-    (`kwargs`) to ``matplotlib.pyplot.pcolormesh()``.
+    (`kwargs`) to ``matplotlib.pyplot.pcolormesh()`` or
+    ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -511,11 +573,20 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
     freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
-    unit : str
-        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+    unit : str, None
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     indices: array like, optional
         Points at which the channels of `signal` were sampled (e.g. azimuth
         angles or x values). `indices` must be monotonously increasing/
@@ -529,6 +600,17 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -548,7 +630,7 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
 
     Returns
@@ -559,10 +641,10 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
         axis of the colorbar. If `colorbar` is ``False``, only the axes on
         which the data is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -585,7 +667,7 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
     with context(style):
         ax, qm, cb = _two_d._time_freq_2d(
             signal, dB_time, dB_freq, log_prefix_time, log_prefix_freq,
-            log_reference, freq_scale, unit, indices, orientation, cmap,
+            log_reference, freq_scale, unit, indices, orientation, method,
             colorbar, ax, **kwargs)
     _utils._tight_layout()
 
@@ -594,7 +676,8 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
         'time_freq_2d', dB_time=dB_time, dB_freq=dB_freq,
         log_prefix_time=log_prefix_time, log_prefix_freq=log_prefix_freq,
         log_reference=log_reference, xscale=freq_scale, unit_time=unit,
-        indices=indices, orientation=orientation, cmap=cmap, colorbar=colorbar)
+        indices=indices, orientation=orientation, method=method,
+        colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax[0].interaction = interaction
@@ -607,13 +690,14 @@ def time_freq_2d(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
 
 def freq_phase_2d(signal, dB=True, log_prefix=None, log_reference=1,
                   freq_scale='log', deg=False, unwrap=False, indices=None,
-                  orientation="vertical", cmap=mpl.cm.get_cmap(name='magma'),
+                  orientation="vertical", method='pcolormesh',
                   colorbar=True, ax=None, style='light', **kwargs):
     """
     2D color coded plot of magnitude and phase spectra (2 by 1 subplot).
 
     Plots ``abs(signal.freq)`` and ``angle(signal.freq)`` and passes keyword
-    arguments (`kwargs`) to ``matplotlib.pyplot.pcolormesh()``.
+    arguments (`kwargs`) to ``matplotlib.pyplot.pcolormesh()`` or
+    ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -652,6 +736,17 @@ def freq_phase_2d(signal, dB=True, log_prefix=None, log_reference=1,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -671,7 +766,7 @@ def freq_phase_2d(signal, dB=True, log_prefix=None, log_reference=1,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
 
     Returns
@@ -682,10 +777,10 @@ def freq_phase_2d(signal, dB=True, log_prefix=None, log_reference=1,
         axis of the colorbar. If `colorbar` is ``False``, only the axes on
         which the data is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -709,14 +804,15 @@ def freq_phase_2d(signal, dB=True, log_prefix=None, log_reference=1,
     with context(style):
         ax, qm, cb = _two_d._freq_phase_2d(
             signal, dB, log_prefix, log_reference, freq_scale, deg, unwrap,
-            indices, orientation, cmap, colorbar, ax, **kwargs)
+            indices, orientation, method, colorbar, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'freq_phase_2d', dB_freq=dB, log_prefix_freq=log_prefix,
         log_reference=log_reference, xscale=freq_scale, deg=deg, unwrap=unwrap,
-        indices=indices, orientation=orientation, cmap=cmap, colorbar=colorbar)
+        indices=indices, orientation=orientation, method=method,
+        colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax[0].interaction = interaction
@@ -728,15 +824,15 @@ def freq_phase_2d(signal, dB=True, log_prefix=None, log_reference=1,
 
 
 def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
-                        unit=None, freq_scale='log', indices=None,
-                        orientation="vertical",
-                        cmap=mpl.cm.get_cmap(name='magma'), colorbar=True,
-                        ax=None, style='light', **kwargs):
+                        unit="s", freq_scale='log', indices=None,
+                        orientation="vertical", method='pcolormesh',
+                        colorbar=True, ax=None, style='light', **kwargs):
     """
     2D color coded plot of magnitude spectra and group delay (2 by 1 subplot).
 
     Plots ``abs(signal.freq)`` and ``pyfar.dsp.group_delay(signal.freq)`` and
-    passes keyword arguments (`kwargs`) to ``matplotlib.pyplot.pcolormesh()``.
+    passes keyword arguments (`kwargs`) to ``matplotlib.pyplot.pcolormesh()``
+    or ``matplotlib.pyplot.contourf()``.
 
     Parameters
     ----------
@@ -753,11 +849,20 @@ def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
     log_reference : integer
         Reference for calculating the logarithmic frequency data. The default
         is ``1``.
-    unit : str
-        Unit of the group delay. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+    unit : str, None
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
@@ -774,6 +879,17 @@ def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
             The channels of `signal` will be plotted as horizontal lines.
 
         The default is ``'vertical'``
+    method: string, optional
+        The Matplotlib plotting method.
+
+        ``'pcolormesh'``
+            Create a pseudocolor plot with a non-regular rectangular grid.
+            The resolution of the data is clearly visible.
+        ``'contourf'``
+            Create a filled contour plot. The data is smoothly interpolated,
+            which might mask the data's resolution.
+
+        The default is ``'pcolormesh'``.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -793,7 +909,7 @@ def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
         ``matplotlib.style.available``. The default is ``light``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
 
     Returns
@@ -804,10 +920,10 @@ def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
         axis of the colorbar. If `colorbar` is ``False``, only the axes on
         which the data is plotted is returned.
     quad_mesh : QuadMesh
-        The Matplotlib quad mesh collection. This can be used to manipulate the
-        way the data is displayed, e.g., by limiting the range of the colormap
-        by ``quad_mesh.set_clim()``. It can also be used to generate a colorbar
-        by ``cb = fig.colorbar(quad_mesh, ...)``.
+        The Matplotlib Quadmesh / QuadContourSet collection. This can be used
+        to manipulate the way the data is displayed, e.g., by limiting the
+        range of the colormap by ``quad_mesh.set_clim()``. It can also be used
+        to generate a colorbar by ``cb = fig.colorbar(quad_mesh, ...)``.
     colorbar : Colorbar
         The Matplotlib colorbar object if `colorbar` is ``True`` and ``None``
         otherwise. This can be used to control the appearance of the colorbar,
@@ -830,14 +946,15 @@ def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
     with context(style):
         ax, qm, cb = _two_d._freq_group_delay_2d(
             signal, dB, log_prefix, log_reference, unit, freq_scale, indices,
-            orientation, cmap, colorbar, ax, **kwargs)
+            orientation, method, colorbar, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'freq_group_delay_2d', dB_freq=dB, log_prefix_freq=log_prefix,
         log_reference=log_reference, xscale=freq_scale, unit_gd=unit,
-        indices=indices, orientation=orientation, cmap=cmap, colorbar=colorbar)
+        indices=indices, orientation=orientation, method=method,
+        colorbar=colorbar)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax[0].interaction = interaction
@@ -849,10 +966,9 @@ def freq_group_delay_2d(signal, dB=True, log_prefix=None, log_reference=1,
 
 
 def spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
-                freq_scale='linear', unit=None, window='hann',
+                freq_scale='linear', unit='s', window='hann',
                 window_length=1024, window_overlap_fct=0.5,
-                cmap=mpl.cm.get_cmap(name='magma'), colorbar=True, ax=None,
-                style='light', yscale=None, **kwargs):
+                colorbar=True, ax=None, style='light', yscale=None, **kwargs):
     """Plot blocks of the magnitude spectrum versus time.
 
     Parameters
@@ -876,10 +992,19 @@ def spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``linear``.
     unit : str, None
-        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
-        ``'samples'``.
-        The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milliseconds), or ``mus`` (microseconds) depending on the data.
+        Set the unit of the time axis.
+
+        ``'s'`` (default)
+            seconds
+        ``'ms'``
+            milliseconds
+        ``'mus'``
+            microseconds
+        ``'samples'``
+            samples
+        ``'auto'``
+            Use seconds, milliseconds, or microseconds depending on the length
+            of the data.
     window : str
         Specifies the window that is applied to each block of the time data
         before applying the Fourier transform. The default is ``hann``. See
@@ -890,8 +1015,6 @@ def spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
         Ratio of indices to overlap between blocks [0...1]. The default is
         ``0.5``, which would result in 512 samples overlap for a window length
         of 1024 samples.
-    cmap : matplotlib.colors.Colormap(name, N=256)
-        Colormap for spectrogram. Defaults to matplotlibs ``magma`` colormap.
     colorbar : bool, optional
         Control the colorbar. The default is ``True``, which adds a colorbar
         to the plot. ``False`` omits the colorbar.
@@ -926,7 +1049,7 @@ def spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
         The default is ``None``.
     **kwargs
         Keyword arguments that are passed to
-        ``matplotlib.pyplot.pcolormesh()``.
+        ``matplotlib.pyplot.pcolormesh()`` or ``matplotlib.pyplot.contourf()``.
 
     Returns
     -------
@@ -969,8 +1092,7 @@ def spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
     with context(style):
         ax, qm, cb = _two_d._spectrogram(
             signal.flatten(), dB, log_prefix, log_reference, freq_scale, unit,
-            window, window_length, window_overlap_fct,
-            cmap, colorbar, ax)
+            window, window_length, window_overlap_fct, colorbar, ax)
     _utils._tight_layout()
 
     # manage interaction
@@ -978,7 +1100,7 @@ def spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
         'spectrogram', dB_freq=dB, log_prefix_freq=log_prefix,
         log_reference=log_reference, yscale=freq_scale, unit_time=unit,
         window=window, window_length=window_length,
-        window_overlap_fct=window_overlap_fct, cmap=cmap)
+        window_overlap_fct=window_overlap_fct)
     interaction = ia.Interaction(
         signal, ax, cb, style, plot_parameter, **kwargs)
     ax.interaction = interaction
